@@ -58,7 +58,7 @@ struct history_t {
 /*
  * return an empty (all zero) history of fixed size (10)
  */
-struct history_t *history_new() {
+struct history_t *history_new(void) {
   struct history_t *root = NULL;
   struct history_t *temp;
   int i;
@@ -248,7 +248,7 @@ GtkWidget *llcheck_bar_new(gint width, gint height,
   /* the result to prepare */
   bar = gtk_hbox_new(FALSE, 0);
   gtk_widget_set_size_request(bar, width, height);
-  gtk_object_set_data(GTK_OBJECT(bar), "width", (gpointer) width);
+  gtk_object_set_data(GTK_OBJECT(bar), "width", GINT_TO_POINTER(width));
 
   /* progress bar: fast/slow relation progressbar */
   progress_bar = gtk_progress_bar_new();
@@ -314,7 +314,7 @@ void llcheck_bar_set(GtkWidget *bar, double max) {
   struct history_t *history =
     (struct history_t *)gtk_object_get_data(GTK_OBJECT(bar), "history");
   double maxmax = history_append(&history, max);
-  int width = (int)gtk_object_get_data(GTK_OBJECT(bar), "width");
+  int width = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(bar), "width"));
       /* saving additional width
 	 (bar->allocation.width is valid only with shown widgets) */
   int pbar1size;
